pub enum ReadImageError {
ImageError(ImageError),
ConvertError(FromDataError),
}Expand description
Errors reported when creating a tensor from an image.
Variants
ImageError(ImageError)
The image could not be loaded.
ConvertError(FromDataError)
The loaded image could not be converted to a tensor.